<?php
namespace XLite\Module\IPAYINTERNATIONAL\MyPOSVirtual\View;

/**
 * Config
 */
class Config extends \XLite\View\AView
{
    /**
     * Get CSS files
     *
     * @return array
     */
    public function getCSSFiles()
    {
        $list = parent::getCSSFiles();

        $list[] = 'modules/IPAYINTERNATIONAL/MyPOSVirtual/config.css';

        return $list;
    }
    
    /**
     * Return widget default template
     *
     * @return string
     */
    protected function getDefaultTemplate()
    {
        return 'modules/IPAYINTERNATIONAL/MyPOSVirtual/config.twig';
    }
}
